@@ -4,18 +4,19 @@ not bound to a specific higher level UP42 object.
 """
 
 import json
+
 from pathlib import Path
 from typing import List, Union, Dict, Optional
-
+from datetime import date, datetime, timedelta
 from geopandas import GeoDataFrame
+
+import requests.exceptions
 import geopandas as gpd
 import pandas as pd
 import shapely
 
 from up42.viztools import folium_base_map, DrawFoliumOverride
-from up42.utils import (
-    get_logger,
-)
+from up42.utils import get_logger, format_time_period
 
 try:
     from IPython import get_ipython
@@ -28,6 +29,18 @@ except (ImportError, AttributeError):
 logger = get_logger(__name__)
 
 
+def check_auth(func, *args, **kwargs):
+    # pylint: disable=unused-argument
+    def inner(self, *args, **kwargs):
+        if not hasattr(self, "auth"):
+            raise Exception(
+                "Requires authentication with UP42, use up42.authenticate()!"
+            )
+        return func(self, *args, **kwargs)
+
+    return inner
+
+
 # pylint: disable=no-member, duplicate-code
 class Tools:
     def __init__(self, auth=None):
@@ -139,6 +152,7 @@ class Tools:
         ).add_to(m)
         return m
 
+    @check_auth
     def get_blocks(
         self,
         block_type: Optional[str] = None,
@@ -161,10 +175,6 @@ class Tools:
             block_type = block_type.lower()  # type: ignore
         except AttributeError:
             pass
-        if not hasattr(self, "auth"):
-            raise Exception(
-                "Requires authentication with UP42, use up42.authenticate()!"
-            )
         url = f"{self.auth._endpoint()}/blocks"
         response_json = self.auth._request(request_type="GET", url=url)
         public_blocks_json = response_json["data"]
@@ -198,6 +208,7 @@ class Tools:
             else:
                 return blocks_json
 
+    @check_auth
     def get_block_details(self, block_id: str, as_dataframe: bool = False) -> dict:
         """
         Gets the detailed information about a specific public block from
@@ -211,10 +222,6 @@ class Tools:
         Returns:
             A dict of the block details metadata for the specific block.
         """
-        if not hasattr(self, "auth"):
-            raise Exception(
-                "Requires authentication with UP42, use up42.authenticate()!"
-            )
         url = f"{self.auth._endpoint()}/blocks/{block_id}"  # public blocks
         response_json = self.auth._request(request_type="GET", url=url)
         details_json = response_json["data"]
@@ -224,6 +231,100 @@ class Tools:
         else:
             return details_json
 
+    @check_auth
+    def get_block_coverage(self, block_id: str) -> dict:
+        # pylint: disable=unused-argument
+        """
+        Gets the spatial coverage of a data/processing block as
+        url or GeoJson Feature Collection.
+
+        Args:
+            block_id: The block id.
+
+        Returns:
+            A dict of the spatial coverage for the specific block.
+        """
+        url = f"{self.auth._endpoint()}/blocks/{block_id}/coverage"
+        response_json = self.auth._request(request_type="GET", url=url)
+        details_json = response_json["data"]
+        response_coverage = requests.get(details_json["url"]).json()
+        return response_coverage
+
+    @check_auth
+    def get_credits_balance(self) -> dict:
+        """
+        Display the overall credits available in your account.
+
+        Returns:
+            A dict with the balance of credits available in your account.
+        """
+        endpoint_url = f"{self.auth._endpoint()}/accounts/me/credits/balance"
+        response_json = self.auth._request(request_type="GET", url=endpoint_url)
+        details_json = response_json["data"]
+        return details_json
+
+    @check_auth
+    def get_credits_history(
+        self,
+        start_date: Optional[Union[str, datetime]] = None,
+        end_date: Optional[Union[str, datetime]] = None,
+    ) -> Dict[str, Union[str, int, Dict]]:
+        """
+        Display the overall credits history consumed in your account.
+        The consumption history will be returned for all workspace_ids on your
+        account.
+        Args:
+            start_date: The start date for the credit consumption search e.g.
+            2021-12-01. Default start_date None uses 2000-01-01.
+            end_date: The end date for the credit consumption search e.g.
+            2021-12-31. Default end_date None uses current date.
+        Returns:
+            A dict with the information of the credit consumption records for
+            all the users linked by the account_id.
+            (see https://docs.up42.com/developers/api#operation/getHistory for
+            output description)
+        """
+        if start_date is None:
+            start_date = "2000-01-01"
+        if end_date is None:
+            tomorrow_date = date.today() + timedelta(days=1)
+            tomorrow_datetime = datetime(
+                year=tomorrow_date.year,
+                month=tomorrow_date.month,
+                day=tomorrow_date.day,
+            )
+            end_date = tomorrow_datetime.strftime("%Y-%m-%d")
+
+        [start_formatted_date, end_formatted_date] = format_time_period(
+            start_date=start_date, end_date=end_date
+        ).split("/")
+        search_parameters = dict(
+            {
+                "from": start_formatted_date,
+                "to": end_formatted_date,
+                "size": 2000,  # 2000 is the maximum page size for this call
+                "page": 0,
+            }
+        )
+        endpoint_url = f"{self.auth._endpoint()}/accounts/me/credits/history"
+        response_json: dict = self.auth._request(
+            request_type="GET", url=endpoint_url, querystring=search_parameters
+        )
+        isLastPage = response_json["data"]["last"]
+        credit_history = response_json["data"]["content"].copy()
+        result = dict(response_json["data"])
+        del result["content"]
+        while not isLastPage:
+            search_parameters["page"] += 1
+            response_json = self.auth._request(
+                request_type="GET", url=endpoint_url, querystring=search_parameters
+            )
+            isLastPage = response_json["data"]["last"]
+            credit_history.extend(response_json["data"]["content"].copy())
+        result["content"] = credit_history
+        return result
+
+    @check_auth
     def validate_manifest(self, path_or_json: Union[str, Path, dict]) -> dict:
         """
         Validates a block manifest json.
@@ -244,10 +345,6 @@ class Tools:
                 manifest_json = json.load(src)
         else:
             manifest_json = path_or_json
-        if not hasattr(self, "auth"):
-            raise Exception(
-                "Requires authentication with UP42, use up42.authenticate()!"
-            )
         url = f"{self.auth._endpoint()}/validate-schema/block"
         response_json = self.auth._request(
             request_type="POST", url=url, data=manifest_json
